@@ -20,6 +20,8 @@ needs_sphinx = '2.0'
 # ua._Function should not be treated as an attribute
 from sphinx.util import inspect
 import scipy._lib.uarray as ua
+from scipy.stats._distn_infrastructure import rv_generic  # noqa: E402
+from scipy.stats._multivariate import multi_rv_generic  # noqa: E402
 old_isdesc = inspect.isdescriptor
 inspect.isdescriptor = (lambda obj: old_isdesc(obj)
                         and not isinstance(obj, ua._Function))
@@ -148,6 +150,7 @@ for key in (
         r"'U' mode is deprecated",  # sphinx io
         r"OpenSSL\.rand is deprecated",  # OpenSSL package in linkcheck
         r"Using or importing the ABCs from",  # 3.5 importlib._bootstrap
+        r"'contextfunction' is renamed to 'pass_context'",  # Jinja
         ):
     warnings.filterwarnings(  # deal with other modules having bad imports
         'ignore', message=".*" + key, category=DeprecationWarning)
@@ -175,11 +178,13 @@ for key in (
 
 html_theme = 'pydata_sphinx_theme'
 
-html_logo = '_static/scipyshiny_small.png'
+html_logo = '_static/logo.svg'
+html_favicon = '_static/favicon.ico'
 
 html_theme_options = {
   "logo_link": "index",
   "github_url": "https://github.com/scipy/scipy",
+  "navbar_start": ["navbar-logo", "version"],
 }
 
 if 'versionwarning' in tags:
@@ -190,9 +195,14 @@ if 'versionwarning' in tags:
            'script.src = "/doc/_static/versionwarning.js";\n'
            'document.head.appendChild(script);');
     html_context = {
-        'VERSIONCHECK_JS': src
+        'VERSIONCHECK_JS': src,
+        'versionwarning': True
     }
     html_js_files = ['versioncheck.js']
+else:
+    html_context = {
+        'versionwarning': False
+    }
 
 html_title = "%s v%s Manual" % (project, version)
 html_static_path = ['_static']
@@ -462,6 +472,12 @@ def linkcode_resolve(domain, info):
         except Exception:
             return None
 
+    # Use the original function object if it is wrapped.
+    obj = getattr(obj, "__wrapped__", obj)
+    # SciPy's distributions are instances of *_gen. Point to this
+    # class since it contains the implementation of all the methods.
+    if isinstance(obj, (rv_generic, multi_rv_generic)):
+        obj = obj.__class__
     try:
         fn = inspect.getsourcefile(obj)
     except Exception:
