@@ -12,6 +12,7 @@ Examples::
     $ python runtests.py --ipython
     $ python runtests.py --python somescript.py
     $ python runtests.py --bench
+    $ python runtests.py --no-build --bench signal.LTI
 
 Run a debugger:
 
@@ -49,6 +50,7 @@ else:
 
 import sys
 import os
+import errno
 # the following multiprocessing import is necessary to prevent tests that use
 # multiprocessing from hanging on >= Python3.8 (macOS) using pytest. Just the
 # import is enough...
@@ -129,7 +131,7 @@ def main(argv):
     parser.add_argument("args", metavar="ARGS", default=[], nargs=REMAINDER,
                         help="Arguments to pass to Nose, Python or shell")
     parser.add_argument("--pep8", action="store_true", default=False,
-                        help="Perform pep8 check with pycodestyle.")
+                        help="Perform pep8 check with flake8.")
     parser.add_argument("--mypy", action="store_true", default=False,
                         help="Run mypy on the codebase")
     parser.add_argument("--doc", action="append", nargs="?",
@@ -138,7 +140,7 @@ def main(argv):
 
     if args.pep8:
         # Lint the source using the configuration in tox.ini.
-        os.system("pycodestyle scipy benchmarks/benchmarks")
+        os.system("flake8 scipy benchmarks/benchmarks")
         # Lint just the diff since branching off of master using a
         # stricter configuration.
         lint_diff = os.path.join(ROOT_DIR, 'tools', 'lint_diff.py')
@@ -171,7 +173,8 @@ def main(argv):
     if not args.no_build:
         site_dir = build_project(args)
         sys.path.insert(0, site_dir)
-        os.environ['PYTHONPATH'] = site_dir
+        os.environ['PYTHONPATH'] = \
+            os.pathsep.join((site_dir, os.environ.get('PYTHONPATH', '')))
 
     extra_argv = args.args[:]
     if extra_argv and extra_argv[0] == '--':
@@ -241,10 +244,13 @@ def main(argv):
             bench_args.extend(['--bench', a])
 
         if not args.bench_compare:
-            cmd = [os.path.join(ROOT_DIR, 'benchmarks', 'run.py'),
-                   'run', '-n', '-e', '--python=same'] + bench_args
-            os.execv(sys.executable, [sys.executable] + cmd)
-            sys.exit(1)
+            import scipy
+            print("Running benchmarks for Scipy version %s at %s"
+                  % (scipy.__version__, scipy.__file__))
+            cmd = ['asv', 'run', '--dry-run', '--show-stderr',
+                   '--python=same'] + bench_args
+            retval = run_asv(cmd)
+            sys.exit(retval)
         else:
             if len(args.bench_compare) == 1:
                 commit_a = args.bench_compare[0]
@@ -276,10 +282,9 @@ def main(argv):
             out, err = p.communicate()
             commit_a = out.strip()
 
-            cmd = [os.path.join(ROOT_DIR, 'benchmarks', 'run.py'),
-                   'continuous', '-e', '-f', '1.05',
+            cmd = ['asv', 'continuous', '--show-stderr', '--factor', '1.05',
                    commit_a, commit_b] + bench_args
-            os.execv(sys.executable, [sys.executable] + cmd)
+            run_asv(cmd)
             sys.exit(1)
 
     if args.build_only:
@@ -386,7 +391,7 @@ def build_project(args):
     # and isn't on the PYTHONPATH. Plus, it has to exist.
     if not os.path.exists(site_dir):
         os.makedirs(site_dir)
-    env['PYTHONPATH'] = site_dir
+    env['PYTHONPATH'] = os.pathsep.join((site_dir, env.get('PYTHONPATH', '')))
 
     log_filename = os.path.join(ROOT_DIR, 'build.log')
     start_time = datetime.datetime.now()
@@ -500,11 +505,11 @@ def run_mypy(args):
 
     try:
         import mypy.api
-    except ImportError:
+    except ImportError as e:
         raise RuntimeError(
             "Mypy not found. Please install it by running "
             "pip install -r mypy_requirements.txt from the repo root"
-        )
+        ) from e
 
     site_dir = build_project(args)
     config = os.path.join(
@@ -527,5 +532,36 @@ def run_mypy(args):
     return status
 
 
+def run_asv(cmd):
+    cwd = os.path.join(os.path.abspath(os.path.dirname(__file__)),
+                       'benchmarks')
+    # Always use ccache, if installed
+    env = dict(os.environ)
+    env['PATH'] = os.pathsep.join(EXTRA_PATH +
+                                  env.get('PATH', '').split(os.pathsep))
+    # Control BLAS/LAPACK threads
+    env['OPENBLAS_NUM_THREADS'] = '1'
+    env['MKL_NUM_THREADS'] = '1'
+
+    # Limit memory usage
+    sys.path.insert(0, cwd)
+    from benchmarks.common import set_mem_rlimit
+    try:
+        set_mem_rlimit()
+    except (ImportError, RuntimeError):
+        pass
+
+    # Run
+    try:
+        return subprocess.call(cmd, env=env, cwd=cwd)
+    except OSError as err:
+        if err.errno == errno.ENOENT:
+            print("Error when running '%s': %s\n" % (" ".join(cmd), str(err),))
+            print("You need to install Airspeed Velocity (https://airspeed-velocity.github.io/asv/)")
+            print("to run Scipy benchmarks")
+            return 1
+        raise
+
+
 if __name__ == "__main__":
     main(argv=sys.argv[1:])
