@@ -5,14 +5,14 @@
 #ifdef _OPENMP
 #include <omp.h>
 #endif
-#include <pythonic/include/types/numpy_texpr.hpp>
 #include <pythonic/include/types/ndarray.hpp>
 #include <pythonic/include/types/int.hpp>
+#include <pythonic/include/types/numpy_texpr.hpp>
 #include <pythonic/include/types/int32.hpp>
-#include <pythonic/types/int32.hpp>
 #include <pythonic/types/ndarray.hpp>
-#include <pythonic/types/int.hpp>
 #include <pythonic/types/numpy_texpr.hpp>
+#include <pythonic/types/int32.hpp>
+#include <pythonic/types/int.hpp>
 #include <pythonic/include/builtins/getattr.hpp>
 #include <pythonic/include/builtins/pythran/and_.hpp>
 #include <pythonic/include/builtins/range.hpp>
@@ -60,24 +60,34 @@ namespace __pythran__group_columns
     {
       typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::ones{})>::type>::type __type0;
       typedef typename std::remove_cv<typename std::remove_reference<argument_type1>::type>::type __type1;
-      typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::intp{})>::type>::type __type2;
-      typedef decltype(std::declval<__type0>()(std::declval<__type1>(), std::declval<__type2>())) __type3;
-      typedef typename pythonic::assignable<decltype(pythonic::operator_::neg(std::declval<__type3>()))>::type __type4;
-      typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::builtins::functor::range{})>::type>::type __type5;
-      typedef decltype(std::declval<__type5>()(std::declval<__type1>())) __type7;
-      typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type7>::type::iterator>::value_type>::type __type8;
-      typedef indexable<__type8> __type9;
-      typedef typename __combined<__type4,__type9>::type __type10;
-      typedef typename pythonic::assignable<long>::type __type11;
-      typedef container<typename std::remove_reference<__type11>::type> __type12;
-      typedef typename __combined<__type10,__type12,__type9,__type12>::type __type13;
-      typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, std::declval<__type13>())) __type14;
-      typedef typename std::tuple_element<0,typename std::remove_reference<__type14>::type>::type __type15;
-      typedef decltype(std::declval<__type5>()(std::declval<__type15>())) __type16;
-      typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type16>::type::iterator>::value_type>::type __type17;
-      typedef indexable<__type17> __type18;
-      typedef typename __combined<__type10,__type18>::type __type19;
-      typedef typename pythonic::returnable<typename __combined<__type19,__type12,__type9,__type12,__type18>::type>::type result_type;
+      typedef __type1 __type2;
+      typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::intp{})>::type>::type __type3;
+      typedef decltype(std::declval<__type0>()(std::declval<__type2>(), std::declval<__type3>())) __type4;
+      typedef decltype(pythonic::operator_::neg(std::declval<__type4>())) __type5;
+      typedef typename pythonic::assignable<__type5>::type __type6;
+      typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::builtins::functor::range{})>::type>::type __type7;
+      typedef decltype(std::declval<__type7>()(std::declval<__type2>())) __type9;
+      typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type9>::type::iterator>::value_type>::type __type10;
+      typedef __type10 __type11;
+      typedef indexable<__type11> __type12;
+      typedef typename __combined<__type6,__type12>::type __type13;
+      typedef long __type14;
+      typedef typename pythonic::assignable<__type14>::type __type15;
+      typedef __type15 __type16;
+      typedef container<typename std::remove_reference<__type16>::type> __type17;
+      typedef typename __combined<__type13,__type17,__type12,__type17>::type __type18;
+      typedef __type18 __type19;
+      typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, std::declval<__type19>())) __type20;
+      typedef typename std::tuple_element<0,typename std::remove_reference<__type20>::type>::type __type21;
+      typedef decltype(std::declval<__type7>()(std::declval<__type21>())) __type22;
+      typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type22>::type::iterator>::value_type>::type __type23;
+      typedef __type23 __type24;
+      typedef indexable<__type24> __type25;
+      typedef typename __combined<__type13,__type25>::type __type26;
+      typedef typename __combined<__type26,__type17,__type12,__type17,__type25>::type __type29;
+      typedef __type29 __type30;
+      typedef typename pythonic::returnable<__type30>::type __type31;
+      typedef __type31 result_type;
     }  
     ;
     template <typename argument_type0 , typename argument_type1 , typename argument_type2 , typename argument_type3 >
@@ -94,24 +104,34 @@ namespace __pythran__group_columns
     {
       typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::ones{})>::type>::type __type0;
       typedef typename std::remove_cv<typename std::remove_reference<argument_type1>::type>::type __type1;
-      typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::intp{})>::type>::type __type2;
-      typedef decltype(std::declval<__type0>()(std::declval<__type1>(), std::declval<__type2>())) __type3;
-      typedef typename pythonic::assignable<decltype(pythonic::operator_::neg(std::declval<__type3>()))>::type __type4;
-      typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::builtins::functor::range{})>::type>::type __type5;
-      typedef decltype(std::declval<__type5>()(std::declval<__type1>())) __type7;
-      typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type7>::type::iterator>::value_type>::type __type8;
-      typedef indexable<__type8> __type9;
-      typedef typename __combined<__type4,__type9>::type __type10;
-      typedef typename pythonic::assignable<long>::type __type11;
-      typedef container<typename std::remove_reference<__type11>::type> __type12;
-      typedef typename __combined<__type10,__type12,__type9,__type12>::type __type13;
-      typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, std::declval<__type13>())) __type14;
-      typedef typename std::tuple_element<0,typename std::remove_reference<__type14>::type>::type __type15;
-      typedef decltype(std::declval<__type5>()(std::declval<__type15>())) __type16;
-      typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type16>::type::iterator>::value_type>::type __type17;
-      typedef indexable<__type17> __type18;
-      typedef typename __combined<__type10,__type18>::type __type19;
-      typedef typename pythonic::returnable<typename __combined<__type19,__type12,__type9,__type12,__type18>::type>::type result_type;
+      typedef __type1 __type2;
+      typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::intp{})>::type>::type __type3;
+      typedef decltype(std::declval<__type0>()(std::declval<__type2>(), std::declval<__type3>())) __type4;
+      typedef decltype(pythonic::operator_::neg(std::declval<__type4>())) __type5;
+      typedef typename pythonic::assignable<__type5>::type __type6;
+      typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::builtins::functor::range{})>::type>::type __type7;
+      typedef decltype(std::declval<__type7>()(std::declval<__type2>())) __type9;
+      typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type9>::type::iterator>::value_type>::type __type10;
+      typedef __type10 __type11;
+      typedef indexable<__type11> __type12;
+      typedef typename __combined<__type6,__type12>::type __type13;
+      typedef long __type14;
+      typedef typename pythonic::assignable<__type14>::type __type15;
+      typedef __type15 __type16;
+      typedef container<typename std::remove_reference<__type16>::type> __type17;
+      typedef typename __combined<__type13,__type17,__type12,__type17>::type __type18;
+      typedef __type18 __type19;
+      typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, std::declval<__type19>())) __type20;
+      typedef typename std::tuple_element<0,typename std::remove_reference<__type20>::type>::type __type21;
+      typedef decltype(std::declval<__type7>()(std::declval<__type21>())) __type22;
+      typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type22>::type::iterator>::value_type>::type __type23;
+      typedef __type23 __type24;
+      typedef indexable<__type24> __type25;
+      typedef typename __combined<__type13,__type25>::type __type26;
+      typedef typename __combined<__type26,__type17,__type12,__type17,__type25>::type __type29;
+      typedef __type29 __type30;
+      typedef typename pythonic::returnable<__type30>::type __type31;
+      typedef __type31 result_type;
     }  
     ;
     template <typename argument_type0 , typename argument_type1 , typename argument_type2 >
@@ -125,55 +145,72 @@ namespace __pythran__group_columns
   {
     typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::ones{})>::type>::type __type0;
     typedef typename std::remove_cv<typename std::remove_reference<argument_type1>::type>::type __type1;
-    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::intp{})>::type>::type __type2;
-    typedef decltype(std::declval<__type0>()(std::declval<__type1>(), std::declval<__type2>())) __type3;
-    typedef typename pythonic::assignable<decltype(pythonic::operator_::neg(std::declval<__type3>()))>::type __type4;
-    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::builtins::functor::range{})>::type>::type __type5;
-    typedef decltype(std::declval<__type5>()(std::declval<__type1>())) __type7;
-    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type7>::type::iterator>::value_type>::type __type8;
-    typedef indexable<__type8> __type9;
-    typedef typename __combined<__type4,__type9>::type __type10;
-    typedef typename pythonic::assignable<long>::type __type11;
-    typedef long __type12;
-    typedef decltype(pythonic::operator_::add(std::declval<__type11>(), std::declval<__type12>())) __type13;
-    typedef typename __combined<__type11,__type13>::type __type14;
-    typedef typename __combined<__type14,__type12>::type __type15;
-    typedef container<typename std::remove_reference<__type15>::type> __type16;
-    typedef typename __combined<__type10,__type16,__type9,__type16>::type __type17;
-    typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, std::declval<__type17>())) __type18;
-    typedef typename std::tuple_element<0,typename std::remove_reference<__type18>::type>::type __type19;
-    typedef decltype(std::declval<__type5>()(std::declval<__type19>())) __type20;
-    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type20>::type::iterator>::value_type>::type __type21;
-    typedef indexable<__type21> __type22;
-    typedef typename __combined<__type10,__type22>::type __type23;
-    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::empty{})>::type>::type __type26;
-    typedef typename std::remove_cv<typename std::remove_reference<argument_type0>::type>::type __type27;
-    typedef typename pythonic::assignable<decltype(std::declval<__type26>()(std::declval<__type27>(), std::declval<__type2>()))>::type __type28;
-    typedef typename std::remove_cv<typename std::remove_reference<argument_type2>::type>::type __type29;
-    typedef typename std::remove_cv<typename std::remove_reference<argument_type3>::type>::type __type30;
-    typedef decltype(std::declval<__type30>()[std::declval<__type8>()]) __type32;
-    typedef decltype(pythonic::operator_::add(std::declval<__type8>(), std::declval<__type12>())) __type35;
-    typedef decltype(std::declval<__type30>()[std::declval<__type35>()]) __type36;
-    typedef decltype(std::declval<__type5>()(std::declval<__type32>(), std::declval<__type36>())) __type37;
-    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type37>::type::iterator>::value_type>::type __type38;
-    typedef decltype(std::declval<__type29>()[std::declval<__type38>()]) __type39;
-    typedef indexable<__type39> __type40;
-    typedef typename __combined<__type28,__type40>::type __type41;
-    typedef decltype(std::declval<__type30>()[std::declval<__type21>()]) __type45;
-    typedef decltype(pythonic::operator_::add(std::declval<__type21>(), std::declval<__type12>())) __type48;
-    typedef decltype(std::declval<__type30>()[std::declval<__type48>()]) __type49;
-    typedef decltype(std::declval<__type5>()(std::declval<__type45>(), std::declval<__type49>())) __type50;
+    typedef __type1 __type2;
+    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::intp{})>::type>::type __type3;
+    typedef decltype(std::declval<__type0>()(std::declval<__type2>(), std::declval<__type3>())) __type4;
+    typedef decltype(pythonic::operator_::neg(std::declval<__type4>())) __type5;
+    typedef typename pythonic::assignable<__type5>::type __type6;
+    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::builtins::functor::range{})>::type>::type __type7;
+    typedef decltype(std::declval<__type7>()(std::declval<__type2>())) __type9;
+    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type9>::type::iterator>::value_type>::type __type10;
+    typedef __type10 __type11;
+    typedef indexable<__type11> __type12;
+    typedef typename __combined<__type6,__type12>::type __type13;
+    typedef long __type14;
+    typedef typename pythonic::assignable<__type14>::type __type15;
+    typedef decltype(pythonic::operator_::add(std::declval<__type15>(), std::declval<__type14>())) __type16;
+    typedef typename __combined<__type15,__type16>::type __type17;
+    typedef typename __combined<__type17,__type14>::type __type18;
+    typedef __type18 __type19;
+    typedef container<typename std::remove_reference<__type19>::type> __type20;
+    typedef typename __combined<__type13,__type20,__type12,__type20>::type __type21;
+    typedef __type21 __type22;
+    typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, std::declval<__type22>())) __type23;
+    typedef typename std::tuple_element<0,typename std::remove_reference<__type23>::type>::type __type24;
+    typedef decltype(std::declval<__type7>()(std::declval<__type24>())) __type25;
+    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type25>::type::iterator>::value_type>::type __type26;
+    typedef __type26 __type27;
+    typedef indexable<__type27> __type28;
+    typedef typename __combined<__type13,__type28>::type __type29;
+    typedef typename __combined<__type29,__type20,__type12,__type20,__type28>::type __type32;
+    typedef typename pythonic::assignable<__type32>::type __type33;
+    typedef typename pythonic::assignable<__type18>::type __type34;
+    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::empty{})>::type>::type __type35;
+    typedef typename std::remove_cv<typename std::remove_reference<argument_type0>::type>::type __type36;
+    typedef __type36 __type37;
+    typedef decltype(std::declval<__type35>()(std::declval<__type37>(), std::declval<__type3>())) __type38;
+    typedef typename pythonic::assignable<__type38>::type __type39;
+    typedef typename std::remove_cv<typename std::remove_reference<argument_type2>::type>::type __type40;
+    typedef __type40 __type41;
+    typedef typename std::remove_cv<typename std::remove_reference<argument_type3>::type>::type __type42;
+    typedef __type42 __type43;
+    typedef decltype(std::declval<__type43>()[std::declval<__type11>()]) __type45;
+    typedef decltype(pythonic::operator_::add(std::declval<__type11>(), std::declval<__type14>())) __type48;
+    typedef decltype(std::declval<__type43>()[std::declval<__type48>()]) __type49;
+    typedef decltype(std::declval<__type7>()(std::declval<__type45>(), std::declval<__type49>())) __type50;
     typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type50>::type::iterator>::value_type>::type __type51;
-    typedef decltype(std::declval<__type29>()[std::declval<__type51>()]) __type52;
-    typedef indexable<__type52> __type53;
-    typedef typename __combined<__type41,__type53>::type __type54;
-    typedef container<typename std::remove_reference<__type12>::type> __type55;
-    typename pythonic::assignable<typename __combined<__type23,__type16,__type9,__type16,__type22>::type>::type groups = pythonic::operator_::neg(pythonic::numpy::functor::ones{}(n, pythonic::numpy::functor::intp{}));
-    typename pythonic::assignable<typename __combined<__type14,__type12>::type>::type current_group = 0L;
-    typename pythonic::assignable<typename __combined<__type54,__type55,__type40,__type53>::type>::type union_ = pythonic::numpy::functor::empty{}(m, pythonic::numpy::functor::intp{});
+    typedef __type51 __type52;
+    typedef decltype(std::declval<__type41>()[std::declval<__type52>()]) __type53;
+    typedef indexable<__type53> __type54;
+    typedef typename __combined<__type39,__type54>::type __type55;
+    typedef decltype(std::declval<__type43>()[std::declval<__type27>()]) __type59;
+    typedef decltype(pythonic::operator_::add(std::declval<__type27>(), std::declval<__type14>())) __type62;
+    typedef decltype(std::declval<__type43>()[std::declval<__type62>()]) __type63;
+    typedef decltype(std::declval<__type7>()(std::declval<__type59>(), std::declval<__type63>())) __type64;
+    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type64>::type::iterator>::value_type>::type __type65;
+    typedef __type65 __type66;
+    typedef decltype(std::declval<__type41>()[std::declval<__type66>()]) __type67;
+    typedef indexable<__type67> __type68;
+    typedef typename __combined<__type55,__type68>::type __type69;
+    typedef container<typename std::remove_reference<__type14>::type> __type70;
+    typedef typename __combined<__type69,__type70,__type54,__type68>::type __type71;
+    typedef typename pythonic::assignable<__type71>::type __type72;
+    __type33 groups = pythonic::operator_::neg(pythonic::numpy::functor::ones{}(n, pythonic::numpy::functor::intp{}));
+    __type34 current_group = 0L;
+    __type72 union_ = pythonic::numpy::functor::empty{}(m, pythonic::numpy::functor::intp{});
     {
-      long  __target139767940641696 = n;
-      for (long  i=0L; i < __target139767940641696; i += 1L)
+      long  __target139832508762624 = n;
+      for (long  i=0L; i < __target139832508762624; i += 1L)
       {
         if (pythonic::operator_::ge(groups[i], 0L))
         {
@@ -183,15 +220,15 @@ namespace __pythran__group_columns
         typename pythonic::lazy<decltype(true)>::type all_grouped = true;
         pythonic::numpy::ndarray::functor::fill{}(union_, 0L);
         {
-          long  __target139767940644672 = indptr[pythonic::operator_::add(i, 1L)];
-          for (long  k=indptr[i]; k < __target139767940644672; k += 1L)
+          long  __target139832508745184 = indptr[pythonic::operator_::add(i, 1L)];
+          for (long  k=indptr[i]; k < __target139832508745184; k += 1L)
           {
             union_[indices[k]] = 1L;
           }
         }
         {
-          long  __target139767940747664 = std::get<0>(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, groups));
-          for (long  j=0L; j < __target139767940747664; j += 1L)
+          long  __target139832508745712 = std::get<0>(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, groups));
+          for (long  j=0L; j < __target139832508745712; j += 1L)
           {
             if (pythonic::operator_::lt(groups[j], 0L))
             {
@@ -203,8 +240,8 @@ namespace __pythran__group_columns
             }
             typename pythonic::lazy<decltype(false)>::type intersect = false;
             {
-              long  __target139767940750064 = indptr[pythonic::operator_::add(j, 1L)];
-              for (long  k_=indptr[j]; k_ < __target139767940750064; k_ += 1L)
+              long  __target139832508658064 = indptr[pythonic::operator_::add(j, 1L)];
+              for (long  k_=indptr[j]; k_ < __target139832508658064; k_ += 1L)
               {
                 if (pythonic::operator_::eq(union_[indices[k_]], 1L))
                 {
@@ -216,8 +253,8 @@ namespace __pythran__group_columns
             if (pythonic::operator_::not_(intersect))
             {
               {
-                long  __target139767940745488 = indptr[pythonic::operator_::add(j, 1L)];
-                for (long  k__=indptr[j]; k__ < __target139767940745488; k__ += 1L)
+                long  __target139832508661616 = indptr[pythonic::operator_::add(j, 1L)];
+                for (long  k__=indptr[j]; k__ < __target139832508661616; k__ += 1L)
                 {
                   union_[indices[k__]] = 1L;
                 }
@@ -244,43 +281,59 @@ namespace __pythran__group_columns
   {
     typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::ones{})>::type>::type __type0;
     typedef typename std::remove_cv<typename std::remove_reference<argument_type1>::type>::type __type1;
-    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::intp{})>::type>::type __type2;
-    typedef decltype(std::declval<__type0>()(std::declval<__type1>(), std::declval<__type2>())) __type3;
-    typedef typename pythonic::assignable<decltype(pythonic::operator_::neg(std::declval<__type3>()))>::type __type4;
-    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::builtins::functor::range{})>::type>::type __type5;
-    typedef decltype(std::declval<__type5>()(std::declval<__type1>())) __type7;
-    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type7>::type::iterator>::value_type>::type __type8;
-    typedef indexable<__type8> __type9;
-    typedef typename __combined<__type4,__type9>::type __type10;
-    typedef typename pythonic::assignable<long>::type __type11;
-    typedef long __type12;
-    typedef decltype(pythonic::operator_::add(std::declval<__type11>(), std::declval<__type12>())) __type13;
-    typedef typename __combined<__type11,__type13>::type __type14;
-    typedef typename __combined<__type14,__type12>::type __type15;
-    typedef container<typename std::remove_reference<__type15>::type> __type16;
-    typedef typename __combined<__type10,__type16,__type9,__type16>::type __type17;
-    typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, std::declval<__type17>())) __type18;
-    typedef typename std::tuple_element<0,typename std::remove_reference<__type18>::type>::type __type19;
-    typedef decltype(std::declval<__type5>()(std::declval<__type19>())) __type20;
-    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type20>::type::iterator>::value_type>::type __type21;
-    typedef indexable<__type21> __type22;
-    typedef typename __combined<__type10,__type22>::type __type23;
-    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::empty{})>::type>::type __type26;
-    typedef typename std::remove_cv<typename std::remove_reference<argument_type0>::type>::type __type27;
-    typedef typename pythonic::assignable<decltype(std::declval<__type26>()(std::declval<__type27>(), std::declval<__type2>()))>::type __type28;
-    typedef typename std::remove_cv<typename std::remove_reference<argument_type2>::type>::type __type29;
-    typedef typename pythonic::assignable<decltype(pythonic::builtins::getattr(pythonic::types::attr::T{}, std::declval<__type29>()))>::type __type30;
-    typedef decltype(std::declval<__type30>()[std::declval<__type21>()]) __type32;
-    typedef decltype(pythonic::operator_::add(std::declval<__type28>(), std::declval<__type32>())) __type33;
-    typedef typename __combined<__type28,__type33>::type __type34;
-    typedef decltype(std::declval<__type30>()[std::declval<__type8>()]) __type37;
+    typedef __type1 __type2;
+    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::intp{})>::type>::type __type3;
+    typedef decltype(std::declval<__type0>()(std::declval<__type2>(), std::declval<__type3>())) __type4;
+    typedef decltype(pythonic::operator_::neg(std::declval<__type4>())) __type5;
+    typedef typename pythonic::assignable<__type5>::type __type6;
+    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::builtins::functor::range{})>::type>::type __type7;
+    typedef decltype(std::declval<__type7>()(std::declval<__type2>())) __type9;
+    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type9>::type::iterator>::value_type>::type __type10;
+    typedef __type10 __type11;
+    typedef indexable<__type11> __type12;
+    typedef typename __combined<__type6,__type12>::type __type13;
+    typedef long __type14;
+    typedef typename pythonic::assignable<__type14>::type __type15;
+    typedef decltype(pythonic::operator_::add(std::declval<__type15>(), std::declval<__type14>())) __type16;
+    typedef typename __combined<__type15,__type16>::type __type17;
+    typedef typename __combined<__type17,__type14>::type __type18;
+    typedef __type18 __type19;
+    typedef container<typename std::remove_reference<__type19>::type> __type20;
+    typedef typename __combined<__type13,__type20,__type12,__type20>::type __type21;
+    typedef __type21 __type22;
+    typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, std::declval<__type22>())) __type23;
+    typedef typename std::tuple_element<0,typename std::remove_reference<__type23>::type>::type __type24;
+    typedef decltype(std::declval<__type7>()(std::declval<__type24>())) __type25;
+    typedef typename std::remove_cv<typename std::iterator_traits<typename std::remove_reference<__type25>::type::iterator>::value_type>::type __type26;
+    typedef __type26 __type27;
+    typedef indexable<__type27> __type28;
+    typedef typename __combined<__type13,__type28>::type __type29;
+    typedef typename __combined<__type29,__type20,__type12,__type20,__type28>::type __type32;
+    typedef typename pythonic::assignable<__type32>::type __type33;
+    typedef typename pythonic::assignable<__type18>::type __type34;
+    typedef typename std::remove_cv<typename std::remove_reference<decltype(pythonic::numpy::functor::empty{})>::type>::type __type35;
+    typedef typename std::remove_cv<typename std::remove_reference<argument_type0>::type>::type __type36;
+    typedef __type36 __type37;
+    typedef decltype(std::declval<__type35>()(std::declval<__type37>(), std::declval<__type3>())) __type38;
+    typedef typename pythonic::assignable<__type38>::type __type39;
+    typedef typename std::remove_cv<typename std::remove_reference<argument_type2>::type>::type __type40;
+    typedef __type40 __type41;
+    typedef decltype(pythonic::builtins::getattr(pythonic::types::attr::T{}, std::declval<__type41>())) __type42;
+    typedef typename pythonic::assignable<__type42>::type __type43;
+    typedef __type43 __type44;
+    typedef decltype(std::declval<__type44>()[std::declval<__type27>()]) __type46;
+    typedef decltype(pythonic::operator_::add(std::declval<__type39>(), std::declval<__type46>())) __type47;
+    typedef typename __combined<__type39,__type47>::type __type48;
+    typedef decltype(std::declval<__type44>()[std::declval<__type11>()]) __type51;
+    typedef typename __combined<__type48,__type51,__type46>::type __type52;
+    typedef typename pythonic::assignable<__type52>::type __type53;
     typename pythonic::assignable_noescape<decltype(pythonic::builtins::getattr(pythonic::types::attr::T{}, A))>::type B = pythonic::builtins::getattr(pythonic::types::attr::T{}, A);
-    typename pythonic::assignable<typename __combined<__type23,__type16,__type9,__type16,__type22>::type>::type groups = pythonic::operator_::neg(pythonic::numpy::functor::ones{}(n, pythonic::numpy::functor::intp{}));
-    typename pythonic::assignable<typename __combined<__type14,__type12>::type>::type current_group = 0L;
-    typename pythonic::assignable<typename __combined<__type34,__type37,__type32>::type>::type union_ = pythonic::numpy::functor::empty{}(m, pythonic::numpy::functor::intp{});
+    __type33 groups = pythonic::operator_::neg(pythonic::numpy::functor::ones{}(n, pythonic::numpy::functor::intp{}));
+    __type34 current_group = 0L;
+    __type53 union_ = pythonic::numpy::functor::empty{}(m, pythonic::numpy::functor::intp{});
     {
-      long  __target139767936400784 = n;
-      for (long  i=0L; i < __target139767936400784; i += 1L)
+      long  __target139832513453600 = n;
+      for (long  i=0L; i < __target139832513453600; i += 1L)
       {
         if (pythonic::operator_::ge(groups[i], 0L))
         {
@@ -290,8 +343,8 @@ namespace __pythran__group_columns
         typename pythonic::lazy<decltype(true)>::type all_grouped = true;
         union_[pythonic::types::contiguous_slice(pythonic::builtins::None,pythonic::builtins::None)] = B[i];
         {
-          long  __target139767937798832 = std::get<0>(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, groups));
-          for (long  j=0L; j < __target139767937798832; j += 1L)
+          long  __target139832508652224 = std::get<0>(pythonic::builtins::getattr(pythonic::types::attr::SHAPE{}, groups));
+          for (long  j=0L; j < __target139832508652224; j += 1L)
           {
             if (pythonic::operator_::lt(groups[j], 0L))
             {
@@ -303,8 +356,8 @@ namespace __pythran__group_columns
             }
             typename pythonic::lazy<decltype(false)>::type intersect = false;
             {
-              long  __target139767937800368 = m;
-              for (long  k=0L; k < __target139767937800368; k += 1L)
+              long  __target139832512276992 = m;
+              for (long  k=0L; k < __target139832512276992; k += 1L)
               {
                 if (pythonic::builtins::pythran::and_([&] () { return pythonic::operator_::gt(union_[k], 0L); }, [&] () { return pythonic::operator_::gt(B[pythonic::types::make_tuple(j, k)], 0L); }))
                 {
@@ -709,8 +762,8 @@ PYTHRAN_MODULE_INIT(_group_columns)(void) {
     if(! theModule)
         PYTHRAN_RETURN;
     PyObject * theDoc = Py_BuildValue("(sss)",
-                                      "0.10.0",
-                                      "2022-02-04 07:45:35.848004",
+                                      "0.11.0",
+                                      "2022-05-16 07:19:56.772736",
                                       "bbd9c32ae0cc40f86da54c6bc74a72b8cc51ed42efd9d0a4f45d3648fc5482c3");
     if(! theDoc)
         PYTHRAN_RETURN;
